@@ -6,12 +6,11 @@ use warnings;
 use open qw/:encoding(UTF-8) :std/;
 
 use Net::Whois::Norid;
-use Net::Whois::Raw;
 
 $Net::Whois::Raw::CHECK_FAIL = 1;
 $Net::Whois::Raw::OMIT_MSG   = 1;
 
-use version; our $VERSION = qv('0.9.1');
+use version; our $VERSION = qv('0.9.2');
 
 use parent qw/Exporter/;
 our @EXPORT_OK = qw/all domain2orgnr num_domains orgnr_ok orgnr2domains/;
@@ -30,7 +29,9 @@ sub domain2orgnr {
 sub num_domains {
     my $orgnr = shift;
 
-    return scalar orgnr2domains($orgnr);
+    my @domains = orgnr2domains($orgnr);
+
+    return scalar @domains;
 }
 
 sub orgnr2domains {
@@ -112,7 +113,7 @@ No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.9.1
+This document describes No::OrgNr version 0.9.2
 
 =head1 SYNOPSIS
 
